
# Slot: was associated with




URI: [ks:was_associated_with](https://w3id.org/linkml/tests/kitchen_sink/was_associated_with)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Agent](Agent.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | prov:wasAssociatedWith |

